/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attribute.attribute;
import static net.sourceforge.writexml.AttributeName.attributeName;
import static net.sourceforge.writexml.AttributeValue.attributeValue;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;

public final class EditTag<T extends MayContainFormTag, SCOPE extends TagScope> extends StandardXhtmlTag<EditTag<T, SCOPE>, XhtmlTag> implements BodyElement<T, SCOPE> {

    private EditTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> deletionTag(final BodyElement<? extends T, ? extends SCOPE>... children) {
        return deletionTag(asList(children));
    }

    static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> deletionTag(final Iterable<BodyElement<? extends T, ? extends SCOPE>> children) {
        return new EditTag<>(tagName("del"), attributes(), children);
    }

    static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> insertionTag(final BodyElement<? extends T, ? extends SCOPE>... children) {
        return insertionTag(asList(children));
    }

    static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> insertionTag(final Iterable<BodyElement<? extends T, ? extends SCOPE>> children) {
        return new EditTag<>(tagName("ins"), attributes(), children);
    }

    @Override
    EditTag<T, SCOPE> makeANewOne(final Attribute attribute) {
        return new EditTag<>(tagName, attributes.append(attribute), children);
    }

    public EditTag<T, SCOPE> withCitation(final Citation citation) {
        return makeANewOne(attribute(attributeName("cite"), attributeValue(citation.asString()), NAMESPACE));
    }

    public EditTag<T, SCOPE> withDateTime(final DateTime dateTime) {
        return makeANewOne(attribute(attributeName("datetime"), attributeValue(dateTime.asString()), NAMESPACE));
    }
}
