/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.AttributeName;
import net.sourceforge.writexml.Attributes;

import java.util.Collections;

import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;

public final class ParameterTag extends BaseXhtmlTag<ParameterTag, XhtmlTag> implements ObjectElement<DoesNotContainFormTag, TagScope.Inline> {

    private ParameterTag(final Attributes attributes) {
        super(tagName("param"), attributes, Collections.<XhtmlTag>emptyList());
    }

    static ParameterTag parameterTag() {
        return new ParameterTag(attributes());
    }

    @Override
    ParameterTag makeANewOne(Attribute attribute) {
        return new ParameterTag(attributes.append(attribute));
    }

    public ParameterTag withName(final ParameterName parameterName) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("name"), net.sourceforge.writexml.AttributeValue.attributeValue(parameterName.asString()), NAMESPACE));
    }

    public ParameterTag withType(final MimeType mimeType) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("type"), net.sourceforge.writexml.AttributeValue.attributeValue(mimeType.asString()), NAMESPACE));
    }

    public ParameterTag withValue(final ParameterValue parameterValue) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("value"), net.sourceforge.writexml.AttributeValue.attributeValue(parameterValue.asString()), NAMESPACE));
    }

    public ParameterTag withValueType(final ParameterValueType parameterValueType) {
        return makeANewOne(Attribute.attribute(AttributeName.attributeName("valuetype"), net.sourceforge.writexml.AttributeValue.attributeValue(parameterValueType.asString()), NAMESPACE));
    }
}
