/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

@SuppressWarnings("UnusedDeclaration")
public final class Tags {
    private Tags() {
    }

    public static AnchorTag anchorTag(final BodyElement<?, TagScope.InlineExceptAnchor>... children) {
        return AnchorTag.anchorTag(children);
    }

    public static AnchorTag anchorTag(final Iterable<? extends BodyElement<?, TagScope.InlineExceptAnchor>> children) {
        return AnchorTag.anchorTag(children);
    }

    public static BodyTag bodyTag(final BodyElement<?, ? extends TagScope.Block>... blockLevelTags) {
        return BodyTag.bodyTag(blockLevelTags);
    }

    public static BodyTag bodyTag(final Iterable<? extends BodyElement<?, ? extends TagScope.Block>> blockLevelTags) {
        return BodyTag.bodyTag(blockLevelTags);
    }

    public static <T extends MayContainFormTag> BlockElement<T> divTag(final BodyElement<? extends T, ?>... bodyElements) {
        return BlockElement.divTag(bodyElements);
    }

    public static <T extends MayContainFormTag> BlockElement<T> divTag(final Iterable<BodyElement<? extends T, ?>> bodyElements) {
        return BlockElement.divTag(bodyElements);
    }

    public static BlockElement<DoesNotContainFormTag> h1Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h1Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h2Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h2Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h3Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h3Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h4Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h4Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h5Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h5Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h6Tag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.h6Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h1Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h1Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h2Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h2Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h3Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h3Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h4Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h4Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h5Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h5Tag(children);
    }

    public static BlockElement<DoesNotContainFormTag> h6Tag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.h6Tag(children);
    }

    public static HeadTag headTag(final TitleTag titleTag, final HeadChild... children) {
        return HeadTag.headTag(titleTag, children);
    }

    public static HeadTag headTag(final TitleTag titleTag, final Iterable<HeadChild> children) {
        return HeadTag.headTag(titleTag, children);
    }

    public static HeadTag headTag(final BaseTag baseTag, final TitleTag titleTag, final HeadChild... children) {
        return HeadTag.headTag(baseTag, titleTag, children);
    }

    public static HeadTag headTag(final BaseTag baseTag, final TitleTag titleTag, final Iterable<HeadChild> children) {
        return HeadTag.headTag(baseTag, titleTag, children);
    }

    public static HtmlTag htmlTag(final HeadTag headTag, final BodyTag bodyTag) {
        return HtmlTag.htmlTag(headTag, bodyTag);
    }

    public static ImageTag imageTag(final ImageSource imageSource, final AlternateText alternateText) {
        return ImageTag.imageTag(imageSource, alternateText);
    }

    public static <T extends MayContainFormTag> ListItemTag<T> listItemTag(final BodyElement<? extends T, ?>... children) {
        return ListItemTag.listItemTag(children);
    }

    public static <T extends MayContainFormTag> ListItemTag<T> listItemTag(final Iterable<BodyElement<? extends T, ?>> children) {
        return ListItemTag.listItemTag(children);
    }

    public static LinkTag linkTag() {
        return LinkTag.linkTag();
    }

    public static MetaTag metaTag(final MetaName name, final MetaContent content) {
        return MetaTag.metaTag(name, content);
    }

    public static MetaTag metaTag(final HttpEquivalent httpEquivalent, final MetaContent content) {
        return MetaTag.metaTag(httpEquivalent, content);
    }

    public static <T extends MayContainFormTag> BlockElement<T> noScriptTag(final BodyElement<? extends T, ? extends TagScope.Block>... children) {
        return BlockElement.noScriptTag(children);
    }

    public static <T extends MayContainFormTag> BlockElement<T> noScriptTag(final Iterable<? extends BodyElement<? extends T, ? extends TagScope.Block>> children) {
        return BlockElement.noScriptTag(children);
    }

    public static <T extends MayContainFormTag> ObjectTag<T> objectTag(final ObjectElement<? extends T, ?>... children) {
        return ObjectTag.objectTag(children);
    }

    public static <T extends MayContainFormTag> ObjectTag<T> objectTag(final Iterable<? extends ObjectElement<? extends T, ?>> children) {
        return ObjectTag.objectTag(children);
    }

    public static <T extends MayContainFormTag> BlockElement<T> orderedListTag(final ListItemTag<? extends T> listItemTag, final ListItemTag<? extends T>... listItemTags) {
        return BlockElement.orderedListTag(listItemTag, listItemTags);
    }

    public static <T extends MayContainFormTag> BlockElement<T> orderedListTag(final ListItemTag<? extends T> listItemTag, final Iterable<ListItemTag<? extends T>> listItemTags) {
        return BlockElement.orderedListTag(listItemTag, listItemTags);
    }

    public static BlockElement<DoesNotContainFormTag> paragraphTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return BlockElement.paragraphTag(children);
    }

    public static BlockElement<DoesNotContainFormTag> paragraphTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return BlockElement.paragraphTag(children);
    }

    public static ScriptTag scriptTag(final MimeType mimeType) {
        return ScriptTag.scriptTag(mimeType);
    }

    public static ScriptTag scriptTag(final MimeType mimeType, final TextElement textElement) {
        return ScriptTag.scriptTag(mimeType, textElement);
    }

    public static TitleTag titleTag(final String title) {
        return TitleTag.titleTag(title);
    }

    public static <T extends MayContainFormTag> BlockElement<T> unorderedListTag(final ListItemTag<? extends T> listItemTag, final ListItemTag<? extends T>... listItemTags) {
        return BlockElement.unorderedListTag(listItemTag, listItemTags);
    }

    public static <T extends MayContainFormTag> BlockElement<T> unorderedListTag(final ListItemTag<? extends T> listItemTag, final Iterable<ListItemTag<? extends T>> listItemTags) {
        return BlockElement.unorderedListTag(listItemTag, listItemTags);
    }

    public static XhtmlText xhtmlText(final String text) {
        return XhtmlText.xhtmlText(text);
    }

    public static XhtmlCdata xhtmlCdata(final String text) {
        return XhtmlCdata.xhtmlCdata(text);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(captionTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(captionTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(captionTag, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(captionTag, tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final TableHeaderTag<? extends T> tableHeaderTag, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(tableHeaderTag, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final TableHeaderTag<? extends T> tableHeaderTag, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(captionTag, tableHeaderTag, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(columnSpecifications, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(columnSpecifications, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(columnSpecifications, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(columnSpecifications, tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(columnSpecifications, tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final TableRowTag<? extends T>... tableRowTags) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableRowTag<? extends T> tableRowTag, final Iterable<TableRowTag<? extends T>> tableRowTags) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableHeaderTag, tableRowTag, tableRowTags);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(columnSpecifications, tableHeaderTag, tableBodyTag);
    }

    public static <T extends MayContainFormTag> TableTag<T> tableTag(final CaptionTag captionTag, final ColumnSpecifications columnSpecifications, final TableHeaderTag<? extends T> tableHeaderTag, final TableBodyTag<? extends T> tableBodyTag) {
        return TableTag.tableTag(captionTag, columnSpecifications, tableHeaderTag, tableBodyTag);
    }

    public static CaptionTag captionTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return CaptionTag.captionTag(children);
    }

    public static CaptionTag captionTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return CaptionTag.captionTag(children);
    }

    public static QuotationTag quotationTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return QuotationTag.quotationTag(children);
    }

    public static QuotationTag quotationTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return QuotationTag.quotationTag(children);
    }

    public static ColumnSpecifications columnSpecifications(final TableColumnDetailsTag columnDetailsTag, final TableColumnDetailsTag... columnDetailsTags) {
        return ColumnSpecifications.columnSpecifications(columnDetailsTag, columnDetailsTags);
    }

    public static ColumnGroupTag columnGroupTag(final ColumnTag... children) {
        return ColumnGroupTag.columnGroupTag(children);
    }

    public static ColumnTag columnTag() {
        return ColumnTag.columnTag();
    }

    public static <T extends MayContainFormTag> TableHeaderTag<T> tableHeaderTag(final TableRowTag<? extends T> child, final TableRowTag<? extends T>... children) {
        return TableHeaderTag.tableHeaderTag(child, children);
    }

    public static <T extends MayContainFormTag> TableHeaderTag<T> tableHeaderTag(final TableRowTag<? extends T> child, final Iterable<TableRowTag<? extends T>> children) {
        return TableHeaderTag.tableHeaderTag(child, children);
    }

    public static <T extends MayContainFormTag> TableFooterTag<T> tableFooterTag(final TableRowTag<? extends T> child, final TableRowTag<? extends T>... children) {
        return TableFooterTag.tableFooterTag(child, children);
    }

    public static <T extends MayContainFormTag> TableRowTag<T> tableRowTag(final TableCellTag<? extends T> child, final TableCellTag<? extends T>... children) {
        return TableRowTag.tableRowTag(child, children);
    }

    public static <T extends MayContainFormTag> TableCellTag<T> tableDataTag(final BodyElement<? extends T, ?>... children) {
        return TableCellTag.tableDataTag(children);
    }

    public static <T extends MayContainFormTag> TableCellTag<T> tableHeaderTag(final BodyElement<? extends T, ?>... children) {
        return TableCellTag.tableHeaderTag(children);
    }

    public static <T extends MayContainFormTag> TableBodyTag<T> tableBodyTag(final TableRowTag<? extends T> child, final TableRowTag<? extends T>... children) {
        return TableBodyTag.tableBodyTag(child, children);
    }

    public static <T extends MayContainFormTag> TableBodyTag<T> tableBodyTag(final TableRowTag<? extends T> child, final Iterable<TableRowTag<? extends T>> children) {
        return TableBodyTag.tableBodyTag(child, children);
    }

    public static InlineTag codeTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.codeTag(children);
    }

    public static InlineTag codeTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.codeTag(children);
    }

    public static InlineTag sampleCodeTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.sampleCodeTag(children);
    }

    public static InlineTag sampleCodeTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.sampleCodeTag(children);
    }

    public static InlineTag abbreviationTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.abbreviationTag(children);
    }

    public static InlineTag abbreviationTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.abbreviationTag(children);
    }

    public static InlineTag superscriptTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.superscriptTag(children);
    }

    public static InlineTag superscriptTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.superscriptTag(children);
    }

    public static InlineTag keyboardTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.keyboardTextTag(children);
    }

    public static InlineTag keyboardTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.keyboardTextTag(children);
    }

    public static InlineTag strongTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.strongTextTag(children);
    }

    public static InlineTag strongTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.strongTextTag(children);
    }

    public static InlineTag citationTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.citationTag(children);
    }

    public static InlineTag citationTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.citationTag(children);
    }

    public static InlineTag definitionTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.definitionTag(children);
    }

    public static InlineTag definitionTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.definitionTag(children);
    }

    public static InlineTag variableTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.variableTag(children);
    }

    public static InlineTag variableTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.variableTag(children);
    }

    public static InlineTag spanTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.spanTag(children);
    }

    public static InlineTag spanTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.spanTag(children);
    }

    public static InlineTag emphasisedTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.emphasisedTextTag(children);
    }

    public static InlineTag emphasisedTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.emphasisedTextTag(children);
    }

    public static InlineTag acronymTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.acronymTag(children);
    }

    public static InlineTag acronymTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.acronymTag(children);
    }

    public static InlineTag subscriptTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.subscriptTag(children);
    }

    public static InlineTag subscriptTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.subscriptTag(children);
    }

    public static InlineTag teletypeTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.teletypeTextTag(children);
    }

    public static InlineTag teletypeTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.teletypeTextTag(children);
    }

    public static InlineTag bigTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.bigTextTag(children);
    }

    public static InlineTag bigTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.bigTextTag(children);
    }

    public static InlineTag boldTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.boldTextTag(children);
    }

    public static InlineTag boldTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.boldTextTag(children);
    }

    public static InlineTag italicTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.italicTextTag(children);
    }

    public static InlineTag italicTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.italicTextTag(children);
    }

    public static InlineTag smallTextTag(final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.smallTextTag(children);
    }

    public static InlineTag smallTextTag(final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.smallTextTag(children);
    }

    public static BlockElement<DoesNotContainFormTag> addressTag(final BodyElement<? extends DoesNotContainFormTag, ? extends TagScope.Inline>... inlineElements) {
        return BlockElement.addressTag(inlineElements);
    }

    public static BlockElement<DoesNotContainFormTag> addressTag(final Iterable<BodyElement<? extends DoesNotContainFormTag, ? extends TagScope.Inline>> inlineElements) {
        return BlockElement.addressTag(inlineElements);
    }

    public static InlineTag bidirectionalOverrideTag(final TextDirection textDirection, final BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>... children) {
        return InlineTag.bidirectionalOverrideTag(textDirection, children);
    }

    public static InlineTag bidirectionalOverrideTag(final TextDirection textDirection, final Iterable<? extends BodyElement<DoesNotContainFormTag, ? extends TagScope.Inline>> children) {
        return InlineTag.bidirectionalOverrideTag(textDirection, children);
    }

    public static BaseTag baseTag(final Href href) {
        return BaseTag.baseTag(href);
    }

    public static <T extends MayContainFormTag> BlockElement<T> blockQuoteTag(final BodyElement<? extends T, TagScope.Block>... children) {
        return BlockElement.blockQuoteTag(children);
    }

    public static <T extends MayContainFormTag> BlockElement<T> blockQuoteTag(final Iterable<? extends BodyElement<? extends T, TagScope.Block>> children) {
        return BlockElement.blockQuoteTag(children);
    }

    public static InlineTag lineBreakTag() {
        return InlineTag.lineBreakTag();
    }

    public static BlockElement<DoesNotContainFormTag> horizontalRuleTag() {
        return BlockElement.horizontalRuleTag();
    }

    public static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> deletionTag(final BodyElement<? extends T, ? extends SCOPE>... children) {
        return EditTag.deletionTag(children);
    }

    public static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> deletionTag(final Iterable<BodyElement<? extends T, ? extends SCOPE>> children) {
        return EditTag.deletionTag(children);
    }

    public static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> insertionTag(final BodyElement<? extends T, ? extends SCOPE>... children) {
        return EditTag.insertionTag(children);
    }

    public static <T extends MayContainFormTag, SCOPE extends TagScope> EditTag<T, SCOPE> insertionTag(final Iterable<BodyElement<? extends T, ? extends SCOPE>> children) {
        return EditTag.insertionTag(children);
    }

    public static FormTag formTag(final Action action, final BodyElement<DoesNotContainFormTag, ? extends TagScope.Block>... children) {
        return FormTag.formTag(action, children);
    }

    public static FormTag formTag(final Action action, final Iterable<? extends BodyElement<? extends DoesNotContainFormTag, ? extends TagScope.Block>> children) {
        return FormTag.formTag(action, children);
    }

    public static InputTag inputTag() {
        return InputTag.inputTag();
    }

    public static TextAreaTag textAreaTag(final Columns columns, final Rows rows) {
        return TextAreaTag.textAreaTag(columns, rows);
    }

    public static TextAreaTag textAreaTag(final Columns columns, final Rows rows, final XhtmlText text) {
        return TextAreaTag.textAreaTag(columns, rows, text);
    }

    public static OptionTag optionTag() {
        return OptionTag.optionTag();
    }

    public static OptionTag optionTag(final XhtmlText text) {
        return OptionTag.optionTag(text);
    }

    public static OptionGroupTag optionGroupTag(final Label label, final OptionTag optionTag, final OptionTag... optionTags) {
        return OptionGroupTag.optionGroupTag(label, optionTag, optionTags);
    }

    public static OptionGroupTag optionGroupTag(final Label label, final OptionTag optionTag, final Iterable<OptionTag> optionTags) {
        return OptionGroupTag.optionGroupTag(label, optionTag, optionTags);
    }

    public static SelectTag selectTag(final SelectTagElement selectTagElement, final SelectTagElement... selectTagElements) {
        return SelectTag.selectTag(selectTagElement, selectTagElements);
    }

    public static SelectTag selectTag(final SelectTagElement selectTagElement, final Iterable<SelectTagElement> selectTagElements) {
        return SelectTag.selectTag(selectTagElement, selectTagElements);
    }

    public static StyleTag styleTag(final MimeType mimeType) {
        return StyleTag.styleTag(mimeType);
    }

    public static StyleTag styleTag(final MimeType mimeType, final TextElement textElement) {
        return StyleTag.styleTag(mimeType, textElement);
    }

    public static <T extends MayContainFormTag> DefinitionTermTag<T> definitionTermTag(final BodyElement<T, ? extends TagScope.Inline>... children) {
        return DefinitionTermTag.definitionTermTag(children);
    }

    public static <T extends MayContainFormTag> DefinitionTermTag<T> definitionTermTag(final Iterable<BodyElement<T, ? extends TagScope.Inline>> children) {
        return DefinitionTermTag.definitionTermTag(children);
    }

    public static <T extends MayContainFormTag> DefinitionDescriptionTag<T> definitionDescriptionTag(final BodyElement<? extends T, ?>... children) {
        return DefinitionDescriptionTag.definitionDescriptionTag(children);
    }

    public static <T extends MayContainFormTag> DefinitionDescriptionTag<T> definitionDescriptionTag(final Iterable<BodyElement<? extends T, ?>> children) {
        return DefinitionDescriptionTag.definitionDescriptionTag(children);
    }

    public static <T extends MayContainFormTag> BlockElement<T> definitionListTag(final DefinitionListContentTag<? extends T> definitionListContentTag, final DefinitionListContentTag<? extends T>... definitionListContentTags) {
        return BlockElement.definitionListTag(definitionListContentTag, definitionListContentTags);
    }

    public static <T extends MayContainFormTag> BlockElement<T> definitionListTag(final DefinitionListContentTag<? extends T> listItemTag, final Iterable<DefinitionListContentTag<? extends T>> listItemTags) {
        return BlockElement.definitionListTag(listItemTag, listItemTags);
    }

    public static ParameterTag parameterTag() {
        return ParameterTag.parameterTag();
    }

    public static LabelTag labelTag(final BodyElement<?, ? extends TagScope.Inline>... children) {
        return LabelTag.labelTag(children);
    }

    public static LabelTag labelTag(final Iterable<? extends BodyElement<?, ? extends TagScope.Inline>> children) {
        return LabelTag.labelTag(children);
    }

    public static LegendTag legendTag(final BodyElement<?, ? extends TagScope.Inline>... children) {
        return LegendTag.legendTag(children);
    }

    public static LegendTag legendTag(final Iterable<? extends BodyElement<?, ? extends TagScope.Inline>> children) {
        return LegendTag.legendTag(children);
    }

    public static <T extends MayContainFormTag> FieldSetTag<T> fieldSetTag(final LegendTag legendTag, final BodyElement<? extends T, ?>... children) {
        return FieldSetTag.fieldSetTag(legendTag, children);
    }

    public static <T extends MayContainFormTag> FieldSetTag<T> fieldSetTag(final LegendTag legendTag, Iterable<? extends BodyElement<? extends T, ?>> children) {
        return FieldSetTag.fieldSetTag(legendTag, children);
    }

}
