/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import net.sourceforge.writexml.Attribute;
import net.sourceforge.writexml.Attributes;
import net.sourceforge.writexml.TagName;

import java.util.Collections;
import java.util.List;

import static java.util.Arrays.asList;
import static net.sourceforge.writexml.Attribute.attribute;
import static net.sourceforge.writexml.AttributeName.attributeName;
import static net.sourceforge.writexml.AttributeValue.attributeValue;
import static net.sourceforge.writexml.Attributes.attributes;
import static net.sourceforge.writexml.TagName.tagName;

public final class TextAreaTag extends SelectableFormElementTag<TextAreaTag> {

    static TextAreaTag textAreaTag(final Columns columns, final Rows rows) {
        return textAreaTag(columns, rows, Collections.<XhtmlTag>emptyList());
    }

    static TextAreaTag textAreaTag(final Columns columns, final Rows rows, final XhtmlText text) {
        return textAreaTag(columns, rows, asList(text));
    }

    private static TextAreaTag textAreaTag(final Columns columns, final Rows rows, final List<? extends XhtmlTag> children) {
        return new TextAreaTag(
                tagName("textarea"),
                attributes(
                        attribute(attributeName("cols"), attributeValue(columns.asString()), NAMESPACE),
                        attribute(attributeName("rows"), attributeValue(rows.asString()), NAMESPACE)
                ),
                children);
    }

    private TextAreaTag(final TagName img, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(img, attributes, children);
    }

    @Override
    TextAreaTag makeANewOne(final Attribute attribute) {
        return new TextAreaTag(tagName, attributes.append(attribute), children);
    }

}
